notify_and_yield

Function notify_and_yield 

pub unsafe fn notify_and_yield(
    task: TaskHandle_t,
    notification: NonZeroU32,
) -> bool
Safety

When calling this function care should be taken to pass a valid FreeRTOS task handle. Moreover, the FreeRTOS task should be valid when this function is being called.